@@ -9,12 +9,18 @@ tests = json.load(f)
 
 class TestKayvee(unittest.TestCase):
 
+  def assertEqualJson(self, a, b):
+    """ Given two strings, assert they are the same json dict """
+    actual = json.loads(a)
+    expected = json.loads(b)
+    self.assertEquals(actual, expected)
+
   def test_format(self):
     for test in tests['format']:
       print "TEST: {}".format(test['title'])
       actual = kv.format(test['input']['data'])
       expected = test['output']
-      self.assertEquals(actual, expected)
+      self.assertEqualJson(actual, expected)
 
   def test_formatLog(self):
     for test in tests['formatLog']:
@@ -26,4 +32,4 @@ class TestKayvee(unittest.TestCase):
         test['input'].get('data', None)
       )
       expected = test['output']
-      self.assertEquals(actual, expected)
+      self.assertEqualJson(actual, expected)
